using System;

namespace Server.Items
{
	// [FlipableAttribute(0x1BD7, 0x1BDA)]
	public abstract class BaseBoards : Item, ICommodity
	{
        private CraftResource m_Resource;

        [CommandProperty( AccessLevel.GameMaster )]
		public CraftResource Resource
		{
			get{ return m_Resource; }
			set{ m_Resource = value; InvalidateProperties(); }
		}

        string ICommodity.Description
        {
            get
            {
                return String.Format(Amount == 1 ? "{0} {1} Board" : "{0} {1} Boards", Amount, CraftResources.GetName(m_Resource).ToLower());
            }
        }

        public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 1 ); // version THIS WAS ONE TO START WITH
			writer.Write( (int) m_Resource );
		}

        public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			switch ( version )
			{
				case 1:
				{
					m_Resource = (CraftResource)reader.ReadInt();
					break;
				}	
                case 0:
				{
					OreInfo info;

					switch ( reader.ReadInt() )
					{
						case 0: info = OreInfo.Iron; break;
						case 1: info = OreInfo.DullCopper; break;
						case 2: info = OreInfo.ShadowIron; break;
						case 3: info = OreInfo.Copper; break;
						case 4: info = OreInfo.Bronze; break;
						case 5: info = OreInfo.Gold; break;
                        case 6: info = OreInfo.Silver; break;
						case 7: info = OreInfo.Agapite; break;
						case 8: info = OreInfo.Verite; break;
						case 9: info = OreInfo.Valorite; break;
                        case 10: info = OreInfo.Uridium; break;
                        case 11: info = OreInfo.Trillium; break;
                        case 12: info = OreInfo.Titanium; break;
                        case 13: info = OreInfo.Platinum; break;
                        case 14: info = OreInfo.Zenite; break;
                        case 15: info = OreInfo.Naquinite; break;
                        case 16: info = OreInfo.Galvinite; break;
                        case 17: info = OreInfo.Trilamide; break;
                        case 18: info = OreInfo.Veramide; break;
                        case 19: info = OreInfo.Zenlamide; break;
						default: info = null; break;
					}

					m_Resource = CraftResources.GetFromOreInfo( info );
					break;
				}
			}
		}

        public BaseBoards (CraftResource resource) : this(resource, 1)
        {
        }

        public BaseBoards (CraftResource resource, int amount) : base(0x1BD7)
        {
            Stackable = true;
            Weight = 1.0;
            Amount = amount;
            Hue = CraftResources.GetHue(resource);

            m_Resource = resource;
        }

		public BaseBoards ( Serial serial ) : base( serial )
		{
		}
        
        public override void AddNameProperty( ObjectPropertyList list )
		{
			if ( Amount > 1 )
				list.Add( 1050039, "{0}\t#{1}", Amount, 1027132 ); // ~1_NUMBER~ ~2_ITEMNAME~
			else
				list.Add( 1027132 ); // ore
		}

        public override void GetProperties( ObjectPropertyList list )
		{
			base.GetProperties( list );

			if ( !CraftResources.IsStandard( m_Resource ) )
			{
				int num = CraftResources.GetLocalizationNumber( m_Resource );

				if ( num > 0 )
					list.Add( num );
				else
					list.Add( CraftResources.GetName( m_Resource ) );
			}
		}

        public override int LabelNumber
		{
			get
			{
                if (m_Resource >= CraftResource.Oak && m_Resource <= CraftResource.FrostWood)
					return 1042845 + (int)(m_Resource - CraftResource.Oak);

				return 1042853; // iron ore;
			}
		}
    }

    public class Board : BaseBoards
    {
		[Constructable]
		public Board() : this(1)
		{
		}

		[Constructable]
        public Board(int amount) : base(CraftResource.RegularLog, amount)
		{
		}

		public Board(Serial serial) : base(serial)
		{
		}

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }

    public class OakBoard : BaseBoards
    {
        [Constructable]
        public OakBoard() : this(1)
        {
        }

        [Constructable]
        public OakBoard(int amount) : base(CraftResource.Oak, amount)
        {
        }

        public OakBoard(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }

    public class AshBoard : BaseBoards
    {
        [Constructable]
        public AshBoard() : this(1)
        {
        }

        [Constructable]
        public AshBoard(int amount) : base(CraftResource.Ash, amount)
        {
        }

        public AshBoard(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }

    public class YewBoard : BaseBoards
    {
        [Constructable]
        public YewBoard() : this(1)
        {
        }

        [Constructable]
        public YewBoard(int amount) : base(CraftResource.Yew, amount)
        {
        }

        public YewBoard(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }

    public class HeartWoodBoard : BaseBoards
    {
        [Constructable]
        public HeartWoodBoard() : this(1)
        {
        }

        [Constructable]
        public HeartWoodBoard(int amount) : base(CraftResource.HeartWood, amount)
        {
        }

        public HeartWoodBoard(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }

    public class BloodWoodBoard : BaseBoards
    {
        [Constructable]
        public BloodWoodBoard() : this(1)
        {
        }

        [Constructable]
        public BloodWoodBoard(int amount) : base(CraftResource.BloodWood, amount)
        {
        }

        public BloodWoodBoard(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }

    public class FrostWoodBoard : BaseBoards
    {
        [Constructable]
        public FrostWoodBoard() : this(1)
        {
        }

        [Constructable]
        public FrostWoodBoard(int amount) : base(CraftResource.FrostWood, amount)
        {
        }

        public FrostWoodBoard(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }
    }
}