using System;
using Server.Items;

namespace Server.Engines.Craft
{
    public class DefCrystalCrafting : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Alchemy;	}
		}

        public override int GumpTitleNumber
        {
            get { return 0; }
        }

        public override string GumpTitleString
        {
            get { return "<basefont color=#FFFFFF><CENTER>CRYSTAL CRAFTING MENU</CENTER></basefont>"; }
        }

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
                    m_CraftSystem = new DefCrystalCrafting();

				return m_CraftSystem;
			}
		}

        public override bool RetainsColorFrom(CraftItem item, Type type)
        {
            return true;
        }

		public override double GetChanceAtMin( CraftItem item )
		{
			return 0.5; // 50%
		}

        private DefCrystalCrafting() : base(1, 1, 1.25)// base( 1, 1, 3.0 )
		{
		}

		public override int CanCraft( Mobile from, BaseTool tool, Type itemType )
		{
			if ( tool.Deleted || tool.UsesRemaining < 0 )
				return 1044038; // You have worn out your tool!
			else if ( !BaseTool.CheckAccessible( tool, from ) )
				return 1044263; // The tool must be on your person to use.

			return 0;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			// no animation
			//if ( from.Body.Type == BodyType.Human && !from.Mounted )
			//	from.Animate( 9, 5, 1, true, false, 0 );

			from.PlaySound( 0x05AA );
		}

		public override int PlayEndingEffect( Mobile from, bool failed, bool lostMaterial, bool toolBroken, int quality, bool makersMark, CraftItem item )
		{
			if ( toolBroken )
				from.SendLocalizedMessage( 1044038 ); // You have worn out your tool

			if ( failed )
			{
				if ( lostMaterial )
					return 1044043; // You failed to create the item, and some of your materials are lost.
				else
					return 1044157; // You failed to create the item, but no materials were lost.
			}
			else
			{
				if ( quality == 0 )
					return 502785; // You were barely able to make this item.  It's quality is below average.
				else if ( makersMark && quality == 2 )
					return 1044156; // You create an exceptional quality item and affix your maker's mark.
				else if ( quality == 2 )
					return 1044155; // You create an exceptional quality item.
				else				
					return 1044154; // You create the item.
			}
		}

		public override void InitCraftList()
		{
			int index = -1;

            // MENUS START HERE

            // Armours
            // index = AddCraft(typeof(YaksCrystalHelm), (string.Format("Armour")), (string.Format("Crystal Helmet")), 90.0, 120.0, typeof(Crystal), 1073160, 25, 502910);
            // index = AddCraft(typeof(CrystalSword), (string.Format("Weapons")), (string.Format("Crystal Sword")), 90.0, 120.0, typeof(Crystal), 1073160, 1000, 502910);

            // WEAPONS
            index = AddCraft(typeof(YaksCrystalMace), (string.Format("Weapons")), (string.Format("[SC] Mace")), 90.0, 120.0, typeof(Crystal), 1073160, 35, 502910);
            index = AddCraft(typeof(YaksCrystalForkOfTheGods), (string.Format("Weapons")), (string.Format("[SC] Fork Of The Gods")), 90.0, 120.0, typeof(Crystal), 1073160, 45, 502910);
            index = AddCraft(typeof(YaksCrystalSpellBlade), (string.Format("Weapons")), (string.Format("[SC] Spell Blade")), 90.0, 120.0, typeof(Crystal), 1073160, 25, 502910);
            index = AddCraft(typeof(YaksCrystalSplinter), (string.Format("Weapons")), (string.Format("[SC] Crystal Splinter")), 90.0, 120.0, typeof(Crystal), 1073160, 15, 502910);
            index = AddCraft(typeof(YaksCrystalCleaver), (string.Format("Weapons")), (string.Format("[SC] Crystal Cleaver")), 90.0, 120.0, typeof(Crystal), 1073160, 15, 502910);

            // DECORATIONS
            // index = AddCraft(typeof(CrystalDeco001), (string.Format("Decorations")), (string.Format("Tall Crystal")), 90.0, 120.0, typeof(Crystal), 1073160, 2500, 502910);
            // index = AddCraft(typeof(CrystalDeco002), (string.Format("Decorations")), (string.Format("Tall Crystal")), 90.0, 120.0, typeof(Crystal), 1073160, 2500, 502910);
            // index = AddCraft(typeof(CrystalPedastal), (string.Format("Decorations")), (string.Format("Crystal Pedastal")), 90.0, 120.0, typeof(Crystal), 1073160, 1500, 502910);

            // JEWELS (RINGS)
            // index = AddCraft(typeof(CrystalRingOfStr), (string.Format("Rings")), (string.Format("Ring of Strength")), 95.0, 140.0, typeof(Crystal), 1073160, 250, 502910);
            // index = AddCraft(typeof(CrystalRingOfInt), (string.Format("Rings")), (string.Format("Ring of Intelligence")), 95.0, 140.0, typeof(Crystal), 1073160, 250, 502910);
            // index = AddCraft(typeof(CrystalRingOfDex), (string.Format("Rings")), (string.Format("Ring of Dexterity")), 95.0, 140.0, typeof(Crystal), 1073160, 250, 502910);
            // index = AddCraft(typeof(CrystalRingOfStam), (string.Format("Rings")), (string.Format("Ring of Stamina")), 95.0, 140.0, typeof(Crystal), 1073160, 250, 502910);

			
            // END OF MENU

            // Set the overidable material
            SetSubRes(typeof(Crystal), 1073160); // 1044041

            // Add every material you want the player to be able to chose from
            // This will overide the overidable material

            AddSubRes( typeof(Crystal),             (string.Format("Normal")),      5.0, 1044351);
            AddSubRes( typeof(AmazoniteCrystal),    (string.Format("Amazonite")),   10.0, 1044351);
            AddSubRes( typeof(AmberCrystal),        (string.Format("Amber")),       15.0, 1044351);
            AddSubRes( typeof(AmethystCrystal),     (string.Format("Amethyst")),    20.0, 1044351);
            AddSubRes( typeof(AragoniteCrystal),    (string.Format("Aragonite")),   25.0, 1044351);
            AddSubRes( typeof(BixbiteCrystal),      (string.Format("Bixbite")),     30.0, 1044351);
            AddSubRes( typeof(BloodStoneCrystal),   (string.Format("BloodStone")),  35.0, 1044351);
            AddSubRes( typeof(CalciteCrystal),      (string.Format("Calcite")),     40.0, 1044351);
            AddSubRes( typeof(GoldStoneCrystal),    (string.Format("GoldStone")),   45.0, 1044351);
            AddSubRes( typeof(LabradoriteCrystal),  (string.Format("Labradorite")), 50.0, 1044351);
            AddSubRes( typeof(MoldaviteCrystal),    (string.Format("Moldavite")),   55.0, 1044351);
            AddSubRes( typeof(MorganiteCrystal),    (string.Format("Morganite")),   60.0, 1044351);
            AddSubRes( typeof(QuartzCrystal),       (string.Format("Quartz")),      65.0, 1044351);
            AddSubRes( typeof(RhodoniteCrystal),    (string.Format("Rhodonite")),   70.0, 1044351);
            AddSubRes( typeof(RubyCrystal),         (string.Format("Ruby")),        75.0, 1044351);
            AddSubRes( typeof(SapphireCrystal),     (string.Format("Sapphire")),    80.0, 1044351);
            AddSubRes( typeof(SugiliteCrystal),     (string.Format("Sugilite")),    85.0, 1044351);
            AddSubRes( typeof(TanzaniteCrystal),    (string.Format("Tanzanite")),   90.0, 1044351);
            AddSubRes( typeof(TurquoiseCrystal),    (string.Format("Turquoise")),   95.0, 1044351);
            AddSubRes( typeof(VarisiteCrystal),     (string.Format("Varisite")),    99.0, 1044351);

			MarkOption = true;
			Repair = Core.AOS;
		}
	}
}