using System; 
using Server.Items; 
using Server.Mobiles; 

namespace Server.Engines.Craft 
{ 
	public class DefPowderCrafting : CraftSystem 
	{ 
		public override SkillName MainSkill 
		{
            get { return SkillName.Alchemy; } 
		}

        public override int GumpTitleNumber
        {
            get { return 0; }
        }

        public override string GumpTitleString
        {
            get { return "<basefont color=#FFFFFF><CENTER>POWDER CRAFTING MENU</CENTER></basefont>"; }
        }

		private static CraftSystem m_CraftSystem; 

		public static CraftSystem CraftSystem 
		{ 
			get 
			{ 
				if ( m_CraftSystem == null )
                    m_CraftSystem = new DefPowderCrafting(); 

				return m_CraftSystem; 
			} 
		} 

		public override double GetChanceAtMin( CraftItem item ) 
		{ 
			return 0.0; // 0% 
		}

        private DefPowderCrafting() : base(1, 1, 1.25)// base( 1, 2, 1.7 ) 
		{ 
		} 

		public override bool RetainsColorFrom( CraftItem item, Type type )
		{
			return true;
		}

		public override int CanCraft( Mobile from, BaseTool tool, Type itemType )
		{
			if ( tool.Deleted || tool.UsesRemaining < 0 )
				return 1044038; // You have worn out your tool!
			else if ( !BaseTool.CheckTool( tool, from ) )
				return 1048146; // If you have a tool equipped, you must use that tool.
			// else if ( !(from is PlayerMobile && ((PlayerMobile)from).Masonry && from.Skills[SkillName.Carpentry].Base >= 100.0) )
			//	return 1044633; // You havent learned stonecraft.
			else if ( !BaseTool.CheckAccessible( tool, from ) )
				return 1044263; // The tool must be on your person to use.

			return 0;
		} 

		public override void PlayCraftEffect( Mobile from ) 
		{ 
			// no effects
			//if ( from.Body.Type == BodyType.Human && !from.Mounted ) 
			//	from.Animate( 9, 5, 1, true, false, 0 ); 
			//new InternalTimer( from ).Start(); 
		} 

		// Delay to synchronize the sound with the hit on the anvil 
		private class InternalTimer : Timer 
		{ 
			private Mobile m_From; 

			public InternalTimer( Mobile from ) : base( TimeSpan.FromSeconds( 0.7 ) ) 
			{ 
				m_From = from; 
			} 

			protected override void OnTick() 
			{ 
				m_From.PlaySound( 0x23D ); 
			} 
		} 

		public override int PlayEndingEffect( Mobile from, bool failed, bool lostMaterial, bool toolBroken, int quality, bool makersMark, CraftItem item ) 
		{ 
			if ( toolBroken ) 
				from.SendLocalizedMessage( 1044038 ); // You have worn out your tool 

			if ( failed ) 
			{ 
				if ( lostMaterial ) 
					return 1044043; // You failed to create the item, and some of your materials are lost. 
				else 
					return 1044157; // You failed to create the item, but no materials were lost. 
			} 
			else 
			{ 
				if ( quality == 0 ) 
					return 502785; // You were barely able to make this item.  It's quality is below average. 
				else if ( makersMark && quality == 2 ) 
					return 1044156; // You create an exceptional quality item and affix your maker's mark. 
				else if ( quality == 2 ) 
					return 1044155; // You create an exceptional quality item. 
				else             
					return 1044154; // You create the item. 
			} 
		} 

		public override void InitCraftList() 
		{
            int index = -1;

			// Decorations
			// AddCraft( typeof( Vase ), 1044501, 1022888, 52.5, 102.5, typeof( Granite ), 1044514, 1, 1044513 );
			// AddCraft( typeof( LargeVase ), 1044501, 1022887, 52.5, 102.5, typeof( Granite ), 1044514, 3, 1044513 );

            // Specialist Dyes
            // index = AddCraft(typeof(PowderResetDye), (string.Format("Specialist Dyes")), (string.Format("Reset Hue Bottle")), 40.0, 80.0, typeof(Powder), 1075802, 10, 502910);
            // index = AddCraft(typeof(PowderSkinDye), (string.Format("Specialist Dyes")), (string.Format("Skin Dye Bottle")), 70.0, 110.0, typeof(Powder), 1075802, 1000, 502910);
            index = AddCraft(typeof(PowderPetDye), (string.Format("Specialist Dyes")), (string.Format("Pet Dye Bottle")), 70.0, 110.0, typeof(Powder), 1075802, 25, 502910);
            // index = AddCraft(typeof(PowderPlantDye), (string.Format("Specialist Dyes")), (string.Format("Plant Dye Bottle")), 70.0, 110.0, typeof(Powder), 1075802, 1000, 502910);
            index = AddCraft(typeof(PowderSpellBookDye), (string.Format("Specialist Dyes")), (string.Format("Spellbook Dye Bottle")), 70.0, 110.0, typeof(Powder), 1075802, 25, 502910);
            index = AddCraft(typeof(PowderLeatherDye), (string.Format("Specialist Dyes")), (string.Format("Leather Dye Bottle")), 70.0, 110.0, typeof(Powder), 1075802, 25, 502910);
            index = AddCraft(typeof(PowderWoodDye), (string.Format("Specialist Dyes")), (string.Format("Wood Dye Bottle")), 70.0, 110.0, typeof(Powder), 1075802, 25, 502910);

            // Crafted Dye Tubs
            // index = AddCraft(typeof(PowderCraftableTub), (string.Format("Specialist Dye Tubs")), (string.Format("Powder Craft Dye Tub")), 70.0, 110.0, typeof(Powder), 1075802, 45, 502910);
            // AddSkill(index, SkillName.Carpentry, 50.0, 55.0);
            // AddRes(index, typeof(BarrelStaves), 1027857, 10, 1044351);

            SetSubRes(typeof(Powder), 1075802);

            AddSubRes(typeof(Powder), (string.Format("Normal Powder")), 5.0, 1075802);
            AddSubRes(typeof(IronPowder), (string.Format("Iron Powder")), 10.0, 1075802);
            AddSubRes(typeof(DullCopperPowder), (string.Format("Dull Copper Powder")), 15.0, 1075802);
            AddSubRes(typeof(ShadowIronPowder), (string.Format("Shadow Powder")), 20.0, 1075802);
            AddSubRes(typeof(CopperPowder), (string.Format("Copper Powder")), 25.0, 1075802);
            AddSubRes(typeof(BronzePowder), (string.Format("Bronze Powder")), 30.0, 1075802);
            AddSubRes(typeof(GoldPowder), (string.Format("Gold Powder")), 35.0, 1075802);
            AddSubRes(typeof(SilverPowder), (string.Format("Silver Powder")), 40.0, 1075802);
            AddSubRes(typeof(AgapitePowder), (string.Format("Agapite Powder")), 45.0, 1075802);
            AddSubRes(typeof(VeritePowder), (string.Format("Verite Powder")), 50.0, 1075802);
            AddSubRes(typeof(ValoritePowder), (string.Format("Valorite Powder")), 55.0, 1075802);
            AddSubRes(typeof(UridiumPowder), (string.Format("Uridium Powder")), 60.0, 1075802);
            AddSubRes(typeof(TrilliumPowder), (string.Format("Trillium Powder")), 65.0, 1075802);
            AddSubRes(typeof(TitaniumPowder), (string.Format("Titanium Powder")), 70.0, 1075802);
            AddSubRes(typeof(PlatinumPowder), (string.Format("Platinum Powder")), 75.0, 1075802);
            AddSubRes(typeof(ZenitePowder), (string.Format("Zenite Powder")), 80.0, 1075802);
            AddSubRes(typeof(NaquinitePowder), (string.Format("Naquinite Powder")), 85.0, 1075802);
            AddSubRes(typeof(GalvinitePowder), (string.Format("Galvinite Powder")), 90.0, 1075802);
            AddSubRes(typeof(TrilamidePowder), (string.Format("Trilamide Powder")), 95.0, 1075802);
            AddSubRes(typeof(VeramidePowder), (string.Format("Veramide Powder")), 96.0, 1075802);
            AddSubRes(typeof(ZenlamidePowder), (string.Format("Zenlamide Powder")), 97.0, 1075802);
            AddSubRes(typeof(EtheralPowder), (string.Format("Etheral Powder")), 98.0, 1075802);

		}
	}
}