using System;
using Server;
using Server.Items;
using Server.Mobiles;
using Server.Targeting;

// from.SendLocalizedMessage(500422); // You can't work on that item. // You can't use an axe on that.
// (502641); // You must equip this item to use it.

namespace Server.Engines.Harvest
{
	public class CrystalGathering : HarvestSystem
	{
		private static CrystalGathering m_System;

		public static CrystalGathering System
		{
			get
			{
				if ( m_System == null )
					m_System = new CrystalGathering();

				return m_System;
			}
		}

		// private HarvestDefinition m_Definition;
        private HarvestDefinition m_Crystals;

        public HarvestDefinition Crystals
        {
            get { return m_Crystals; }
        }

		// public HarvestDefinition Definition
		// {
        //    get { return m_Crystals; }
		// }

        private CrystalGathering()
		{
			HarvestResource[] res;
			HarvestVein[] veins;

            #region CrystalGathering
            // HarvestDefinition crystals = new HarvestDefinition();
            HarvestDefinition crystals = m_Crystals = new HarvestDefinition();

			// Resource banks are every 4x3 tiles
            crystals.BankWidth = 4;
            crystals.BankHeight = 3;

			// Every bank holds from 20 to 45 logs
            crystals.MinTotal = 10;
            crystals.MaxTotal = 150;

			// A resource bank will respawn its content every 20 to 30 minutes
            crystals.MinRespawn = TimeSpan.FromMinutes(5.0);
            crystals.MaxRespawn = TimeSpan.FromMinutes(10.0);

			// Skill checking is done on the Lumberjacking skill
            crystals.Skill = SkillName.Alchemy;

			// Set the list of harvestable tiles
            crystals.Tiles = m_CrystalTiles;

			// Players must be within 2 tiles to harvest
            crystals.MaxRange = 2;

			// Ten logs per harvest action
            crystals.ConsumedPerHarvest = 10;
            crystals.ConsumedPerFeluccaHarvest = 20;

			// The chopping effect
            crystals.EffectActions = new int[] { 13 };
            crystals.EffectSounds = new int[] { 0x41 };
            crystals.EffectCounts = new int[] { 1, 2, 2, 2, 3 };
            crystals.EffectDelay = TimeSpan.FromSeconds(1.6);
            crystals.EffectSoundDelay = TimeSpan.FromSeconds(0.9);

            crystals.NoResourcesMessage = 500333; // You are to weary to discern anything useful. //  There's not enough wood here to harvest.
            crystals.FailMessage = 1072558; // The crystal patterns shift dramatically!
            crystals.OutOfRangeMessage = 500446; // That is too far away.
            crystals.PackFullMessage = 502868; // Your backpack is too full. // You can't place any wood into your backpack!
            crystals.ToolBrokeMessage = 1005152; // something broke SEVERELY!!!! // You broke your axe.

			res = new HarvestResource[]
				{
                    // NUMBERS BELOW ARE...
                    // 1st Required Skill Needed
                    // 2nd Min Skill Needed
                    // 3rd Max Skill Needed
                    // 4th Success Message CLI No

					new HarvestResource( 00.0, 05.0, 040.0, ( string.Format( "You chip away some Normal Crystal and put it in your bag" )),         typeof( Crystal ),          typeof ( CrystalElemental) ),
                    new HarvestResource( 02.5, 10.0, 045.0, ( string.Format( "You chip away some Amazonite Crystal and put it in your bag" )),      typeof( AmazoniteCrystal ), typeof ( AmazoniteCrystalElemental) ),
                    new HarvestResource( 05.0, 15.0, 050.0, ( string.Format( "You chip away some Amber Crystal and put it in your bag" )),          typeof( AmberCrystal ),     typeof ( AmberCrystalElemental) ),
                    new HarvestResource( 10.0, 20.0, 055.0, ( string.Format( "You chip away some Amethyst Crystal and put it in your bag" )),       typeof( AmethystCrystal ),  typeof ( AmethystCrystalElemental) ),
                    new HarvestResource( 15.0, 25.0, 060.0, ( string.Format( "You chip away some Aragonite Crystal and put it in your bag" )),      typeof( AragoniteCrystal ), typeof ( AragoniteCrystalElemental) ),
                    new HarvestResource( 20.0, 30.0, 065.0, ( string.Format( "You chip away some Bixbite Crystal and put it in your bag" )),        typeof( BixbiteCrystal ),   typeof ( BixbiteCrystalElemental) ),
                    new HarvestResource( 25.9, 35.0, 070.0, ( string.Format( "You chip away some BloodStone Crystal and put it in your bag" )),     typeof( BloodStoneCrystal ),    typeof ( BloodStoneCrystalElemental) ),
                    new HarvestResource( 30.0, 40.0, 075.0, ( string.Format( "You chip away some Calcite Crystal and put it in your bag" )),        typeof( CalciteCrystal ),   typeof ( CalciteCrystalElemental) ),
                    new HarvestResource( 35.0, 45.0, 080.0, ( string.Format( "You chip away some GoldStone Crystal and put it in your bag" )),      typeof( GoldStoneCrystal ), typeof ( GoldStoneCrystalElemental) ),
                    new HarvestResource( 40.0, 50.0, 085.0, ( string.Format( "You chip away some Labradorite Crystal and put it in your bag" )),    typeof( LabradoriteCrystal ),   typeof ( LabradoriteCrystalElemental) ),
                    new HarvestResource( 45.0, 55.0, 090.0, ( string.Format( "You chip away some Moldavite Crystal and put it in your bag" )),      typeof( MoldaviteCrystal ),     typeof ( MoldaviteCrystalElemental) ),
                    new HarvestResource( 50.0, 60.0, 095.0, ( string.Format( "You chip away some Morganite Crystal and put it in your bag" )),      typeof( MorganiteCrystal ), typeof ( MorganiteCrystalElemental) ),
                    new HarvestResource( 55.0, 65.0, 100.0, ( string.Format( "You chip away some Quartz Crystal and put it in your bag" )),         typeof( QuartzCrystal ),    typeof ( QuartzCrystalElemental) ),
                    new HarvestResource( 60.0, 70.0, 105.0, ( string.Format( "You chip away some Rhodonite Crystal and put it in your bag" )),      typeof( RhodoniteCrystal ), typeof ( RhodoniteCrystalElemental) ),
                    new HarvestResource( 65.0, 75.0, 110.0, ( string.Format( "You chip away some Ruby Crystal and put it in your bag" )),           typeof( RubyCrystal ),      typeof ( RubyCrystalElemental) ),
                    new HarvestResource( 70.0, 80.0, 115.0, ( string.Format( "You chip away some Sapphire Crystal and put it in your bag" )),       typeof( SapphireCrystal ),  typeof ( SapphireCrystalElemental) ),
                    new HarvestResource( 75.0, 85.0, 120.0, ( string.Format( "You chip away some Sapphire Crystal and put it in your bag" )),       typeof( SugiliteCrystal ),  typeof ( SugiliteCrystalElemental) ),
                    new HarvestResource( 80.0, 90.0, 125.0, ( string.Format( "You chip away some Tanzanite Crystal and put it in your bag" )),      typeof( TanzaniteCrystal ), typeof ( TanzaniteCrystalElemental) ),
                    new HarvestResource( 85.0, 95.0, 130.0, ( string.Format( "You chip away some Turquoise Crystal and put it in your bag" )),      typeof( TurquoiseCrystal ), typeof ( TurquoiseCrystalElemental) ),
                    new HarvestResource( 90.0, 99.0, 135.0, ( string.Format( "You chip away some Varisite Crystal and put it in your bag" )),       typeof( VarisiteCrystal ),  typeof ( VarisiteCrystalElemental) )
				};

			veins = new HarvestVein[]
				{
                    // NUMBERS BELOW ARE...
                    // 1ST Vein Chance
                    // 2ND Chance To Fallback
                    // 3RD Primary Resource
                    // 4TH Fallback Resource

					new HarvestVein( 36.0, 0.0, res[0], null   ),
                    new HarvestVein( 20.0, 0.2, res[1], res[0] ),
                    new HarvestVein( 10.0, 0.2, res[2], res[0] ),
                    new HarvestVein( 05.0, 0.2, res[3], res[0] ),
                    new HarvestVein( 04.0, 0.2, res[4], res[0] ),
                    new HarvestVein( 04.0, 0.2, res[5], res[0] ),
                    new HarvestVein( 03.0, 0.2, res[6], res[0] ),
                    new HarvestVein( 03.0, 0.2, res[7], res[0] ),
                    new HarvestVein( 03.0, 0.2, res[8], res[0] ),
                    new HarvestVein( 03.0, 0.2, res[9], res[0] ),
                    new HarvestVein( 02.0, 0.2, res[10], res[0] ),
                    new HarvestVein( 02.0, 0.2, res[11], res[0] ),
                    new HarvestVein( 02.0, 0.2, res[12], res[0] ),
                    new HarvestVein( 01.0, 0.2, res[13], res[0] ),
                    new HarvestVein( 01.0, 0.2, res[14], res[0] ),
                    new HarvestVein( 00.0, 0.2, res[15], res[0] ),
                    new HarvestVein( 00.4, 0.2, res[16], res[0] ),
                    new HarvestVein( 00.3, 0.2, res[17], res[0] ),
                    new HarvestVein( 00.2, 0.2, res[18], res[0] ),
                    new HarvestVein( 00.1, 0.2, res[19], res[0] ),
				};

            crystals.Resources = res;
            crystals.Veins = veins;

            // m_Definition = crystals;
            Definitions.Add(crystals);
			#endregion
		}

        // ADDED FOR THE ELLIES
        public override Type GetResourceType(Mobile from, Item tool, HarvestDefinition def, Map map, Point3D loc, HarvestResource resource)
        {
            if (def == m_Crystals)
            {
                if (from is PlayerMobile && from.Skills[SkillName.Alchemy].Base >= 100.0 && 0.1 > Utility.RandomDouble())
                    return resource.Types[1];

                return resource.Types[0];
            }

            return base.GetResourceType(from, tool, def, map, loc, resource);
        }

        public override bool CheckHarvest(Mobile from, Item tool)
        {
            if (!base.CheckHarvest(from, tool))
                return false;

            if (from.Mounted)
            {
                from.SendLocalizedMessage(501864); // You can't mine while riding.
                return false;
            }
            else if (from.IsBodyMod && !from.Body.IsHuman)
            {
                from.SendLocalizedMessage(501865); // You can't mine while polymorphed.
                return false;
            }

            return true;
        }

        public override void SendSuccessTo(Mobile from, Item item, HarvestResource resource)
        {
            if (item is BaseGranite)
                from.SendLocalizedMessage(1044606); // You carefully extract some workable stone from the ore vein!
            else
                base.SendSuccessTo(from, item, resource);
        }

        public override bool CheckHarvest(Mobile from, Item tool, HarvestDefinition def, object toHarvest)
        {
            if (!base.CheckHarvest(from, tool, def, toHarvest))
                return false;

            // if (def == m_Sand && !(from is PlayerMobile && from.Skills[SkillName.Mining].Base >= 100.0 && ((PlayerMobile)from).SandMining))
            // {
            //     OnBadHarvestTarget(from, tool, toHarvest);
            //    return false;
            // }
            else if (from.Mounted)
            {
                from.SendLocalizedMessage(501864); // You can't mine while riding.
                return false;
            }
            else if (from.IsBodyMod && !from.Body.IsHuman)
            {
                from.SendLocalizedMessage(501865); // You can't mine while polymorphed.
                return false;
            }

            return true;
        }

        public override HarvestVein MutateVein(Mobile from, Item tool, HarvestDefinition def, HarvestBank bank, object toHarvest, HarvestVein vein)
        {
            if (tool is CrystalPickaxe && def == m_Crystals)
            {
                int veinIndex = Array.IndexOf(def.Veins, vein);

                if (veinIndex >= 0 && veinIndex < (def.Veins.Length - 1))
                    return def.Veins[veinIndex + 1];
            }

            return base.MutateVein(from, tool, def, bank, toHarvest, vein);
        }

        private static int[] m_Offsets = new int[]
			{
				-1, -1,
				-1,  0,
				-1,  1,
				 0, -1,
				 0,  1,
				 1, -1,
				 1,  0,
				 1,  1
			};

        public override void OnHarvestFinished(Mobile from, Item tool, HarvestDefinition def, HarvestVein vein, HarvestBank bank, HarvestResource resource, object harvested)
        {
            if (tool is CrystalPickaxe && def == m_Crystals && 0.1 > Utility.RandomDouble())
            {
                HarvestResource res = vein.PrimaryResource;

                if (res == resource && res.Types.Length >= 1)
                {
                    try
                    {
                        Map map = from.Map;

                        if (map == null)
                            return;

                        BaseCreature spawned = Activator.CreateInstance(res.Types[1], new object[] { 25 }) as BaseCreature;

                        if (spawned != null)
                        {
                            int offset = Utility.Random(8) * 2; // THIS WAS SET TO 8 NOT 14

                            for (int i = 0; i < m_Offsets.Length; i += 2)
                            {
                                int x = from.X + m_Offsets[(offset + i) % m_Offsets.Length];
                                int y = from.Y + m_Offsets[(offset + i + 1) % m_Offsets.Length];

                                if (map.CanSpawnMobile(x, y, from.Z))
                                {
                                    spawned.MoveToWorld(new Point3D(x, y, from.Z), map);
                                    spawned.Combatant = from;
                                    return;
                                }
                                else
                                {
                                    int z = map.GetAverageZ(x, y);

                                    if (map.CanSpawnMobile(x, y, z))
                                    {
                                        spawned.MoveToWorld(new Point3D(x, y, z), map);
                                        spawned.Combatant = from;
                                        return;
                                    }
                                }
                            }

                            spawned.MoveToWorld(from.Location, from.Map);
                            spawned.Combatant = from;
                        }
                    }
                    catch
                    {
                    }
                }
            }
        }

        public override bool BeginHarvesting(Mobile from, Item tool)
        {
            if (!base.BeginHarvesting(from, tool))
                return false;

            // from.SendLocalizedMessage(503033); // Where do you wish to dig?
            from.SendMessage(62, "Which crystal do you wish to work on ?");
            return true;
        }

        public override void OnBadHarvestTarget(Mobile from, Item tool, object toHarvest)
        {
            if (toHarvest is LandTarget)
                // from.SendLocalizedMessage(501862); // You can't mine there.
                from.SendMessage(32, "You can't harvest there.");
            else
                //from.SendLocalizedMessage(501863); // You can't mine that.
                from.SendMessage(32, "You Can't harvest that.");
        }

		#region Tile lists
		private static int[] m_CrystalTiles = new int[]
			{
                0x6206, 0x6207, 0x6208, 0x6209, 0x620A, 0x620B, 0x620C, 0x620D,
                0x620E, 0x6210, 0x6211, 0x6212, 0x6213, 0x6214, 0x6215, 0x6216,
                0x6217, 0x6218, 0x621A, 0x621B, 0x621C, 0x621D, 0x621E, 0x621F,
                0x6220, 0x6221, 0x6222, 0x6224, 0x6225, 0x6226, 0x6227, 0x6228,
                0x6229, 0x622A, 0x622B, 0x622C
			};
		#endregion
	}
}