using System;
using Server.Items;

namespace Server.Items
{
	public abstract class BaseCrystal : Item, ICommodity
	{
        private CraftResource m_Resource;

        [CommandProperty( AccessLevel.GameMaster )]
		public CraftResource Resource
		{
			get{ return m_Resource; }
			set{ m_Resource = value; InvalidateProperties(); }
		}

        string ICommodity.Description
        {
            get
            {
                return String.Format(Amount == 1 ? "{0} {1} Crystal" : "{0} {1} Crystals", Amount, CraftResources.GetName(m_Resource).ToLower());
            }
        }

        public abstract BaseCrystal GetCrystals();

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 1 ); // version THIS WAS ONE TO START WITH
			writer.Write( (int) m_Resource );
		}

        public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			switch ( version )
			{
				case 1:
				{
					m_Resource = (CraftResource)reader.ReadInt();
					break;
				}	
                case 0:
				{
					OreInfo info;

					switch ( reader.ReadInt() )
					{
						case 0: info = OreInfo.Iron; break;
						
						default: info = null; break;
					}

					m_Resource = CraftResources.GetFromOreInfo( info );
					break;
				}
			}
		}

        public BaseCrystal ( CraftResource resource ) : this( resource, 1 )
		{
		}

		public BaseCrystal ( CraftResource resource, int amount ) : base( 0x3194 ) // 0x3194
		{
			Stackable = true;
			Weight = 0.2;
			Amount = amount;
			Hue = CraftResources.GetHue( resource );

			m_Resource = resource;
		}

        public BaseCrystal (Serial serial) : base(serial)
		{
		}

        public override void AddNameProperty( ObjectPropertyList list )
		{
			if ( Amount > 1 )
                list.Add(1050039, "{0}\t#{1}", Amount, 1073160); // ~1_NUMBER~ ~2_ITEMNAME~
			else
                list.Add(1073160); // ore - log
		}

        public override void GetProperties( ObjectPropertyList list )
		{
			base.GetProperties( list );

			if ( !CraftResources.IsStandard( m_Resource ) )
			{
				int num = CraftResources.GetLocalizationNumber( m_Resource );

				if ( num > 0 )
					list.Add( num );
				else
					list.Add( CraftResources.GetName( m_Resource ) );
			}
		}

        public override int LabelNumber
		{
			get
			{
                if (m_Resource >= CraftResource.Amazonite && m_Resource <= CraftResource.Varisite)
                    return 1042845 + (int)(m_Resource - CraftResource.Amazonite);

                return 1073160; // iron ore;
			}
		}
    }

    public class Crystal : BaseCrystal
	{
		[Constructable]
		public Crystal() : this( 1 )
		{
		}

		[Constructable]
        public Crystal(int amount) : base(CraftResource.RegularCrystal, amount)
		{
		}

        public Crystal(Serial serial) : base(serial)
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}

        public override BaseCrystal GetCrystals()
        {
            return new Crystal ();
        }
	}

    public class AmazoniteCrystal : BaseCrystal
    {
        [Constructable]
        public AmazoniteCrystal() : this(1)
        {
        }

        [Constructable]
        public AmazoniteCrystal(int amount) : base(CraftResource.Amazonite, amount)
        {
        }

        public AmazoniteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new AmazoniteCrystal();
        }
    }

    public class AmberCrystal : BaseCrystal
    {
        [Constructable]
        public AmberCrystal() : this(1)
        {
        }

        [Constructable]
        public AmberCrystal(int amount) : base(CraftResource.Amber, amount)
        {
        }

        public AmberCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new AmberCrystal();
        }
    }

    public class AmethystCrystal : BaseCrystal
    {
        [Constructable]
        public AmethystCrystal() : this(1)
        {
        }

        [Constructable]
        public AmethystCrystal(int amount) : base(CraftResource.Amethyst, amount)
        {
        }

        public AmethystCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new AmethystCrystal();
        }
    }

    public class AragoniteCrystal : BaseCrystal
    {
        [Constructable]
        public AragoniteCrystal() : this(1)
        {
        }

        [Constructable]
        public AragoniteCrystal(int amount) : base(CraftResource.Aragonite, amount)
        {
        }

        public AragoniteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new AragoniteCrystal();
        }
    }

    public class BixbiteCrystal : BaseCrystal
    {
        [Constructable]
        public BixbiteCrystal() : this(1)
        {
        }

        [Constructable]
        public BixbiteCrystal(int amount) : base(CraftResource.Bixbite, amount)
        {
        }

        public BixbiteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new BixbiteCrystal();
        }
    }

    public class BloodStoneCrystal : BaseCrystal
    {
        [Constructable]
        public BloodStoneCrystal() : this(1)
        {
        }

        [Constructable]
        public BloodStoneCrystal(int amount) : base(CraftResource.BloodStone, amount)
        {
        }

        public BloodStoneCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new BloodStoneCrystal();
        }
    }

    public class CalciteCrystal : BaseCrystal
    {
        [Constructable]
        public CalciteCrystal() : this(1)
        {
        }

        [Constructable]
        public CalciteCrystal(int amount) : base(CraftResource.Calcite, amount)
        {
        }

        public CalciteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new CalciteCrystal();
        }
    }

    public class GoldStoneCrystal : BaseCrystal
    {
        [Constructable]
        public GoldStoneCrystal() : this(1)
        {
        }

        [Constructable]
        public GoldStoneCrystal(int amount) : base(CraftResource.GoldStone, amount)
        {
        }

        public GoldStoneCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new GoldStoneCrystal();
        }
    }

    public class LabradoriteCrystal : BaseCrystal
    {
        [Constructable]
        public LabradoriteCrystal() : this(1)
        {
        }

        [Constructable]
        public LabradoriteCrystal(int amount) : base(CraftResource.Labradorite, amount)
        {
        }

        public LabradoriteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new LabradoriteCrystal();
        }
    }

    public class MoldaviteCrystal : BaseCrystal
    {
        [Constructable]
        public MoldaviteCrystal() : this(1)
        {
        }

        [Constructable]
        public MoldaviteCrystal(int amount) : base(CraftResource.Moldavite, amount)
        {
        }

        public MoldaviteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new MoldaviteCrystal();
        }
    }

    public class MorganiteCrystal : BaseCrystal
    {
        [Constructable]
        public MorganiteCrystal() : this(1)
        {
        }

        [Constructable]
        public MorganiteCrystal(int amount) : base(CraftResource.Morganite, amount)
        {
        }

        public MorganiteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new MorganiteCrystal();
        }
    }

    public class QuartzCrystal : BaseCrystal
    {
        [Constructable]
        public QuartzCrystal() : this(1)
        {
        }

        [Constructable]
        public QuartzCrystal(int amount) : base(CraftResource.Quartz, amount)
        {
        }

        public QuartzCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new QuartzCrystal();
        }
    }

    public class RhodoniteCrystal : BaseCrystal
    {
        [Constructable]
        public RhodoniteCrystal() : this(1)
        {
        }

        [Constructable]
        public RhodoniteCrystal(int amount) : base(CraftResource.Rhodonite, amount)
        {
        }

        public RhodoniteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new RhodoniteCrystal();
        }
    }

    public class RubyCrystal : BaseCrystal
    {
        [Constructable]
        public RubyCrystal() : this(1)
        {
        }

        [Constructable]
        public RubyCrystal(int amount) : base(CraftResource.Ruby, amount)
        {
        }

        public RubyCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new RubyCrystal();
        }
    }

    public class SapphireCrystal : BaseCrystal
    {
        [Constructable]
        public SapphireCrystal() : this(1)
        {
        }

        [Constructable]
        public SapphireCrystal(int amount) : base(CraftResource.Sapphire, amount)
        {
        }

        public SapphireCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new SapphireCrystal();
        }
    }

    public class SugiliteCrystal : BaseCrystal
    {
        [Constructable]
        public SugiliteCrystal() : this(1)
        {
        }

        [Constructable]
        public SugiliteCrystal(int amount) : base(CraftResource.Sugilite, amount)
        {
        }

        public SugiliteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new SugiliteCrystal();
        }
    }

    public class TanzaniteCrystal : BaseCrystal
    {
        [Constructable]
        public TanzaniteCrystal() : this(1)
        {
        }

        [Constructable]
        public TanzaniteCrystal(int amount) : base(CraftResource.Tanzanite, amount)
        {
        }

        public TanzaniteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new TanzaniteCrystal();
        }
    }

    public class TurquoiseCrystal : BaseCrystal
    {
        [Constructable]
        public TurquoiseCrystal() : this(1)
        {
        }

        [Constructable]
        public TurquoiseCrystal(int amount) : base(CraftResource.Turquoise, amount)
        {
        }

        public TurquoiseCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new TurquoiseCrystal();
        }
    }

    public class VarisiteCrystal : BaseCrystal
    {
        [Constructable]
        public VarisiteCrystal() : this(1)
        {
        }

        [Constructable]
        public VarisiteCrystal(int amount) : base(CraftResource.Varisite, amount)
        {
        }

        public VarisiteCrystal(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseCrystal GetCrystals()
        {
            return new VarisiteCrystal();
        }
    }
}