using System;
using Server.Items;

namespace Server.Items
{
	// [FlipableAttribute( 0x1bdd, 0x1be0 )]
	public abstract class BaseLog : Item, ICommodity
	{
        private CraftResource m_Resource;

        [CommandProperty( AccessLevel.GameMaster )]
		public CraftResource Resource
		{
			get{ return m_Resource; }
			set{ m_Resource = value; InvalidateProperties(); }
		}

        string ICommodity.Description
        {
            get
            {
                return String.Format(Amount == 1 ? "{0} {1} Log" : "{0} {1} Logs", Amount, CraftResources.GetName(m_Resource).ToLower());
            }
        }

        public abstract BaseLog GetLogs();

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 1 ); // version THIS WAS ONE TO START WITH
			writer.Write( (int) m_Resource );
		}

        public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();

			switch ( version )
			{
				case 1:
				{
					m_Resource = (CraftResource)reader.ReadInt();
					break;
				}	
                case 0:
				{
					OreInfo info;

					switch ( reader.ReadInt() )
					{
						case 0: info = OreInfo.Iron; break;
						case 1: info = OreInfo.DullCopper; break;
						case 2: info = OreInfo.ShadowIron; break;
						case 3: info = OreInfo.Copper; break;
						case 4: info = OreInfo.Bronze; break;
						case 5: info = OreInfo.Gold; break;
                        case 6: info = OreInfo.Silver; break;
						case 7: info = OreInfo.Agapite; break;
						case 8: info = OreInfo.Verite; break;
						case 9: info = OreInfo.Valorite; break;
                        case 10: info = OreInfo.Uridium; break;
                        case 11: info = OreInfo.Trillium; break;
                        case 12: info = OreInfo.Titanium; break;
                        case 13: info = OreInfo.Platinum; break;
                        case 14: info = OreInfo.Zenite; break;
                        case 15: info = OreInfo.Naquinite; break;
                        case 16: info = OreInfo.Galvinite; break;
                        case 17: info = OreInfo.Trilamide; break;
                        case 18: info = OreInfo.Veramide; break;
                        case 19: info = OreInfo.Zenlamide; break;
						default: info = null; break;
					}

					m_Resource = CraftResources.GetFromOreInfo( info );
					break;
				}
			}
		}

        public BaseLog ( CraftResource resource ) : this( resource, 1 )
		{
		}

		public BaseLog ( CraftResource resource, int amount ) : base( 0x1BDD )
		{
            // Name = "Logs";
			Stackable = true;
			Weight = 2.0;
			Amount = amount;
			Hue = CraftResources.GetHue( resource );

			m_Resource = resource;
		}

		public BaseLog( Serial serial ) : base( serial )
		{
		}

        public override void AddNameProperty( ObjectPropertyList list )
		{
			if ( Amount > 1 )
				list.Add( 1050039, "{0}\t#{1}", Amount, 1044466 ); // ~1_NUMBER~ ~2_ITEMNAME~
			else
                list.Add( 1044466 ); // ore - log
            // if (Amount > 1)
            //    list.Add(1050039, "{0}\t#{1}", Amount, Name.ToString() ); // ~1_NUMBER~ ~2_ITEMNAME~
            //else
            //    list.Add(Name.ToString()); // ore
		}

        public override void GetProperties( ObjectPropertyList list )
		{
			base.GetProperties( list );

			if ( !CraftResources.IsStandard( m_Resource ) )
			{
				int num = CraftResources.GetLocalizationNumber( m_Resource );

				if ( num > 0 )
					list.Add( num );
				else
					list.Add( CraftResources.GetName( m_Resource ) );
			}
		}

        public override int LabelNumber
		{
			get
			{
                if (m_Resource >= CraftResource.Oak && m_Resource <= CraftResource.FrostWood)
					return 1042845 + (int)(m_Resource - CraftResource.Oak);

				return 1044466; // iron ore;
			}
		}
    }

    public class Log : BaseLog
	{
		[Constructable]
		public Log() : this( 1 )
		{
		}

		[Constructable]
        public Log(int amount) : base(CraftResource.RegularLog, amount)
		{
		}

		public Log( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}

        public override BaseLog GetLogs()
        {
            return new Log();
        }
	}

    // MAKE NEW LOG TYPES HERE

    public class OakLog : BaseLog
    {
        [Constructable]
        public OakLog() : this(1)
        {
        }

        [Constructable]
        public OakLog(int amount) : base(CraftResource.Oak, amount)
        {
        }

        public OakLog(Serial serial) : base(serial)
        {
        }


        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseLog GetLogs()
        {
            return new OakLog();
        }
    }

    public class AshLog : BaseLog
    {
        [Constructable]
        public AshLog() : this(1)
        {
        }

        [Constructable]
        public AshLog(int amount) : base(CraftResource.Ash, amount)
        {
        }

        public AshLog(Serial serial) : base(serial)
        {
        }


        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseLog GetLogs()
        {
            return new AshLog();
        }
    }

    public class YewLog : BaseLog
    {
        [Constructable]
        public YewLog() : this(1)
        {
        }

        [Constructable]
        public YewLog (int amount) : base(CraftResource.Yew, amount)
        {
        }

        public YewLog(Serial serial) : base(serial)
        {
        }


        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseLog GetLogs()
        {
            return new YewLog();
        }
    }

    public class HeartWoodLog : BaseLog
    {
        [Constructable]
        public HeartWoodLog() : this(1)
        {
        }

        [Constructable]
        public HeartWoodLog(int amount) : base(CraftResource.HeartWood, amount)
        {
        }

        public HeartWoodLog(Serial serial) : base(serial)
        {
        }


        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseLog GetLogs()
        {
            return new HeartWoodLog();
        }
    }

    public class BloodWoodLog : BaseLog
    {
        [Constructable]
        public BloodWoodLog() : this(1)
        {
        }

        [Constructable]
        public BloodWoodLog(int amount) : base(CraftResource.BloodWood, amount)
        {
        }

        public BloodWoodLog(Serial serial) : base(serial)
        {
        }


        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseLog GetLogs()
        {
            return new BloodWoodLog();
        }
    }

    public class FrostWoodLog : BaseLog
    {
        [Constructable]
        public FrostWoodLog() : this(1)
        {
        }

        [Constructable]
        public FrostWoodLog(int amount) : base(CraftResource.FrostWood, amount)
        {
        }

        public FrostWoodLog(Serial serial) : base(serial)
        {
        }


        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        public override BaseLog GetLogs()
        {
            return new FrostWoodLog();
        }
    }
}