using System;
using Server.Network;
using Server.Prompts;
using Server.Items;
using Server.Targeting;
using Server.Mobiles;

namespace Server.Items
{
    public class PowderLeatherDyeTarget : Target // Create our targeting class (which we derive from the base target class)
    {
        private PowderLeatherDye m_PowderLeatherDye;
        private Mobile m_from;

        public PowderLeatherDyeTarget(PowderLeatherDye powderleatherdye) : base(1, false, TargetFlags.None)
        {
            m_PowderLeatherDye = powderleatherdye;
        }

        protected override void OnTarget(Mobile from, object target) // Override the protected OnTarget() for our feature
        {
            if (m_PowderLeatherDye.Deleted)
                return;

            if (target is BaseArmor && (((BaseArmor)target).MaterialType == ArmorMaterialType.Leather || ((BaseArmor)target).MaterialType == ArmorMaterialType.Studded))
            {
                BaseArmor basearmor = (BaseArmor)target;

                bool okay = (basearmor.IsChildOf(from.Backpack));

                if (!okay)
                {
                    from.SendMessage("The Leather Must Be In Your Backpack");
                }

                else if (okay)
                {
                    basearmor.Hue = m_PowderLeatherDye.Hue;
                    from.SendMessage("You Dye The Leather");
                    m_PowderLeatherDye.Delete();
                    from.PlaySound(0x23E);
                }
            }
            else
            {
                from.SendMessage("This Dye Only Works On Leathers"); // Not the right target type
            }
        }
    }

    public class PowderLeatherDye : Item
    {
        [Constructable]
        public PowderLeatherDye() : base(0xE26)
        {
            base.Weight = 1.0;
            base.Name = "A Leather Dye Bottle";
        }

        public override void GetProperties(ObjectPropertyList list)
        {
            base.GetProperties(list);

            if (Hue == 0x15)
                list.Add(string.Format("Normal Leather Dye"));
            if (Hue == 0x763)
                list.Add(string.Format("Iron Leather Dye"));
            if (Hue == 0x973)
                list.Add(string.Format("Dull Copper Leather Dye"));
            if (Hue == 0x966)
                list.Add(string.Format("Shadow Leather Dye"));
            if (Hue == 0x96D)
                list.Add(string.Format("Copper Leather Dye"));
            if (Hue == 0x972)
                list.Add(string.Format("Bronze Leather Dye"));
            if (Hue == 0x8A5)
                list.Add(string.Format("Gold Leather Dye"));
            else if (Hue == 0x835)
                list.Add(string.Format("Silver Leather Dye"));
            else if (Hue == 0x979)
                list.Add(string.Format("Agapite Leather Dye"));
            else if (Hue == 0x89F)
                list.Add(string.Format("Verite Leather Dye"));
            else if (Hue == 0x8AB)
                list.Add(string.Format("Valorite Leather Dye"));
            else if (Hue == 0x583)
                list.Add(string.Format("Uridium Leather Dye"));
            else if (Hue == 0x91)
                list.Add(string.Format("Trillium Leather Dye"));
            else if (Hue == 0xBD)
                list.Add(string.Format("Titanium Leather Dye"));
            else if (Hue == 0x4D5)
                list.Add(string.Format("Platinum Leather Dye"));
            else if (Hue == 0xA4)
                list.Add(string.Format("Zenite Leather Dye"));
            else if (Hue == 0x2DD)
                list.Add(string.Format("Naquinite Leather Dye"));
            else if (Hue == 0x849)
                list.Add(string.Format("Galvinite Leather Dye"));
            else if (Hue == 0x674)
                list.Add(string.Format("Trilamide Leather Dye"));
            else if (Hue == 0x11C)
                list.Add(string.Format("Veramide Leather Dye"));
            else if (Hue == 0x47F)
                list.Add(string.Format("Zenlamide Leather Dye"));
            else if (Hue == 0x45)
                list.Add(string.Format("Etheral Leather Dye"));
        }

        public PowderLeatherDye(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        // DYE ACTION

        public override void OnDoubleClick(Mobile from) // Override double click of the deed to call our target
        {
            if (!IsChildOf(from.Backpack)) // Make sure its in their pack
            {
                from.SendMessage("The Bottle Must Be In Your Backpack To Use It."); // That must be in your pack for you to use it.
            }
            else
            {
                from.SendMessage("Which Leather Do You Want To Dye?");
                from.Target = new PowderLeatherDyeTarget(this); // Call target
            }
        }
    }
}


