using System;
using Server.Network;
using Server.Prompts;
using Server.Items;
using Server.Targeting;
using Server.Mobiles;

namespace Server.Items
{
    public class PowderPetDyeTarget : Target // Create our targeting class (which we derive from the base target class)
    {
        private PowderPetDye m_PowderPetDye;
        private Mobile m_from;

        public PowderPetDyeTarget(PowderPetDye powderpetdye) : base(1, false, TargetFlags.None)
        {
            m_PowderPetDye = powderpetdye;
        }

        protected override void OnTarget(Mobile from, object target) // Override the protected OnTarget() for our feature
        {
            if (m_PowderPetDye.Deleted)
                return;

            if (target is BaseCreature)
            {
                BaseCreature creature = (BaseCreature)target;
                
                if (creature.Controlled == false)
                {
                    from.SendMessage("This Dye Only Works On Tamed Pets");
                }
                else
                {
                    // *******************************
                    if (creature.ControlMaster != from)
                    {
                        from.SendMessage("You Can't Go Round Colouring Other Peoples Pets !!!");
                    }
                    else
                    // Player Checking = Player Pets
                    {
                        creature.Hue = m_PowderPetDye.Hue;
                        from.SendMessage("You Dye Your Pet, It Doesn't Look Impressed About It Tho !!!");
                        m_PowderPetDye.Delete();
                        from.PlaySound(0x23E);
                    }
                }
            }
            else
            {
                from.SendMessage("This Dye Only Works On Pets"); // ONLY PETS
            }
        }
    }

    public class PowderPetDye : Item
    {
        [Constructable]
        public PowderPetDye() : base(0xE26)
        {
            base.Weight = 1.0;
            base.Name = "A Pet Dye Bottle";
        }

        public override void GetProperties(ObjectPropertyList list)
        {
            base.GetProperties(list);

            if (Hue == 0x15)
                list.Add(string.Format("Normal Pet Dye"));
            if (Hue == 0x763)
                list.Add(string.Format("Iron Pet Dye"));
            if (Hue == 0x973)
                list.Add(string.Format("Dull Copper Pet Dye"));
            if (Hue == 0x966)
                list.Add(string.Format("Shadow Pet Dye"));
            if (Hue == 0x96D)
                list.Add(string.Format("Copper Pet Dye"));
            if (Hue == 0x972)
                list.Add(string.Format("Bronze Pet Dye"));
            if (Hue == 0x8A5)
                list.Add(string.Format("Gold Pet Dye"));
            else if (Hue == 0x835)
                list.Add(string.Format("Silver Pet Dye"));
            else if (Hue == 0x979)
                list.Add(string.Format("Agapite Pet Dye"));
            else if (Hue == 0x89F)
                list.Add(string.Format("Verite Pet Dye"));
            else if (Hue == 0x8AB)
                list.Add(string.Format("Valorite Pet Dye"));
            else if (Hue == 0x583)
                list.Add(string.Format("Uridium Pet Dye"));
            else if (Hue == 0x91)
                list.Add(string.Format("Trillium Pet Dye"));
            else if (Hue == 0xBD)
                list.Add(string.Format("Titanium Pet Dye"));
            else if (Hue == 0x4D5)
                list.Add(string.Format("Platinum Pet Dye"));
            else if (Hue == 0xA4)
                list.Add(string.Format("Zenite Pet Dye"));
            else if (Hue == 0x2DD)
                list.Add(string.Format("Naquinite Pet Dye"));
            else if (Hue == 0x849)
                list.Add(string.Format("Galvinite Pet Dye"));
            else if (Hue == 0x674)
                list.Add(string.Format("Trilamide Pet Dye"));
            else if (Hue == 0x11C)
                list.Add(string.Format("Veramide Pet Dye"));
            else if (Hue == 0x47F)
                list.Add(string.Format("Zenlamide Pet Dye"));
            else if (Hue == 0x45)
                list.Add(string.Format("Etheral Pet Dye"));
        }

        public PowderPetDye(Serial serial)
            : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        // DYE ACTION

        public override void OnDoubleClick(Mobile from) // Override double click of the deed to call our target
        {
            if (!IsChildOf(from.Backpack)) // Make sure its in their pack
            {
                from.SendMessage("The Bottle Must Be In Your Backpack To Use It."); // That must be in your pack for you to use it.
            }
            else
            {
                from.SendMessage("Which Pet Do You Want To Dye?");
                from.Target = new PowderPetDyeTarget(this); // Call target
            }
        }
    }
}


