using System;
using Server.Network;
using Server.Prompts;
using Server.Items;
using Server.Targeting;
using Server.Mobiles;

namespace Server.Items
{
    public class PowderResetDyeTarget : Target // Create our targeting class (which we derive from the base target class)
    {
        private PowderResetDye m_PowderResetDye;
        private Mobile m_from;

        public PowderResetDyeTarget(PowderResetDye powderresetdye) : base(1, false, TargetFlags.None)
        {
            m_PowderResetDye = powderresetdye;
        }

        protected override void OnTarget(Mobile from, object target) // Override the protected OnTarget() for our feature
        {
            if (m_PowderResetDye.Deleted)
                return;

            if ((target is BaseBoards) || (target is BaseCreature) || (target is BaseBoards))
            {
                BaseBoards baseboards= (BaseBoards)target;

                bool okay = (baseboards.IsChildOf(from.Backpack));

                if (!okay)
                {
                    from.SendMessage("The Wooden Boards Must Be In Your Backpack");
                }

                else if (okay)
                {
                    baseboards.Hue = m_PowderResetDye.Hue;
                    from.SendMessage("You Dye The Wood");
                    m_PowderResetDye.Delete();
                    from.PlaySound(0x23E);
                }
            }
            else
            {
                from.SendMessage("This Dye Only Works On Items In The Powder Crafting Menu."); // Not the right target type
            }
        }
    }

    public class PowderResetDye : Item
    {
        [Constructable]
        public PowderResetDye() : base(0xE26)
        {
            base.Weight = 1.0;
            base.Name = "A Reset Hue Bottle";
            base.Hue = 1153;
        }

        public PowderResetDye(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        // DYE ACTION

        public override void OnDoubleClick(Mobile from) // Override double click of the deed to call our target
        {
            if (!IsChildOf(from.Backpack)) // Make sure its in their pack
            {
                from.SendMessage("The Bottle Must Be In Your Backpack To Use It."); // That must be in your pack for you to use it.
            }
            else
            {
                from.SendMessage("Which item do you with to reset the hue of?");
                from.Target = new PowderResetDyeTarget(this); // Call target
            }
        }
    }
}


