using System;
using Server.Network;
using Server.Prompts;
using Server.Items;
using Server.Targeting;
using Server.Mobiles;

namespace Server.Items
{
    public class PowderSpellBookDyeTarget : Target // Create our targeting class (which we derive from the base target class)
    {
        private PowderSpellBookDye m_PowderSpellBookDye;
        private Mobile m_from;

        public PowderSpellBookDyeTarget(PowderSpellBookDye powderspellbookdye) : base(1, false, TargetFlags.None)
        {
            m_PowderSpellBookDye = powderspellbookdye;
        }

        protected override void OnTarget(Mobile from, object target) // Override the protected OnTarget() for our feature
        {
            if (m_PowderSpellBookDye.Deleted)
                return;

            if (target is Spellbook)
            {
                Spellbook spellbook = (Spellbook)target;

                bool okay = (spellbook.IsChildOf(from.Backpack));

                if (!okay)
                {
                    from.SendMessage("The Spellbook Must Be In Your Backpack");
                }

                else if (okay)
                {
                    spellbook.Hue = m_PowderSpellBookDye.Hue;
                    from.SendMessage("You Dye The Spellbook");
                    m_PowderSpellBookDye.Delete();
                    from.PlaySound(0x23E);
                }
            }
            else
            {
                from.SendMessage("This Dye Only Works On Spellbooks"); // Not the right target type
            }
        }
    }

	public class PowderSpellBookDye : Item
	{
		[Constructable]
        public PowderSpellBookDye() : base(0xE26)
		{
			base.Weight = 1.0;
			base.Name = "A Spellbook Dye Bottle";
		}

        public override void GetProperties(ObjectPropertyList list)
        {
            base.GetProperties(list);

            if (Hue == 0x15)
                list.Add(string.Format("Normal Spellbook Dye"));
            if (Hue == 0x763)
                list.Add(string.Format("Iron Spellbook Dye"));
            if (Hue == 0x973)
                list.Add(string.Format("Dull Copper Spellbook Dye"));
            if (Hue == 0x966)
                list.Add(string.Format("Shadow Spellbook Dye"));
            if (Hue == 0x96D)
                list.Add(string.Format("Copper Spellbook Dye"));
            if (Hue == 0x972)
                list.Add(string.Format("Bronze Spellbook Dye"));
            if (Hue == 0x8A5)
                list.Add(string.Format("Gold Spellbook Dye"));
            else if (Hue == 0x835)
                list.Add(string.Format("Silver Spellbook Dye"));
            else if (Hue == 0x979)
                list.Add(string.Format("Agapite Spellbook Dye"));
            else if (Hue == 0x89F)
                list.Add(string.Format("Verite Spellbook Dye"));
            else if (Hue == 0x8AB)
                list.Add(string.Format("Valorite Spellbook Dye"));
            else if (Hue == 0x583)
                list.Add(string.Format("Uridium Spellbook Dye"));
            else if (Hue == 0x91)
                list.Add(string.Format("Trillium Spellbook Dye"));
            else if (Hue == 0xBD)
                list.Add(string.Format("Titanium Spellbook Dye"));
            else if (Hue == 0x4D5)
                list.Add(string.Format("Platinum Spellbook Dye"));
            else if (Hue == 0xA4)
                list.Add(string.Format("Zenite Spellbook Dye"));
            else if (Hue == 0x2DD)
                list.Add(string.Format("Naquinite Spellbook Dye"));
            else if (Hue == 0x849)
                list.Add(string.Format("Galvinite Spellbook Dye"));
            else if (Hue == 0x674)
                list.Add(string.Format("Trilamide Spellbook Dye"));
            else if (Hue == 0x11C)
                list.Add(string.Format("Veramide Spellbook Dye"));
            else if (Hue == 0x47F)
                list.Add(string.Format("Zenlamide Spellbook Dye"));
            else if (Hue == 0x45)
                list.Add(string.Format("Etheral Spellbook Dye"));
        }

        public PowderSpellBookDye(Serial serial) : base(serial)
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}

        // DYE ACTION

        public override void OnDoubleClick(Mobile from) // Override double click of the deed to call our target
        {
            if (!IsChildOf(from.Backpack)) // Make sure its in their pack
            {
                from.SendMessage("The Bottle Must Be In Your Backpack To Use It."); // That must be in your pack for you to use it.
            }
            else
            {
                from.SendMessage("Which Spellbook Do You Want To Dye?"); // What item would you like to bless? (Clothes Only)
                from.Target = new PowderSpellBookDyeTarget(this); // Call our target
            }
        }
    }
}


