using System;
using Server.Network;
using Server.Prompts;
using Server.Items;
using Server.Targeting;
using Server.Mobiles;

namespace Server.Items
{
    public class PowderWoodDyeTarget : Target // Create our targeting class (which we derive from the base target class)
    {
        private PowderWoodDye m_PowderWoodDye;
        private Mobile m_from;

        public PowderWoodDyeTarget(PowderWoodDye powderwooddye) : base(1, false, TargetFlags.None)
        {
            m_PowderWoodDye = powderwooddye;
        }

        protected override void OnTarget(Mobile from, object target) // Override the protected OnTarget() for our feature
        {
            if (m_PowderWoodDye.Deleted)
                return;

            if (target is BaseBoards)
            {
                BaseBoards baseboards= (BaseBoards)target;

                bool okay = (baseboards.IsChildOf(from.Backpack));

                if (!okay)
                {
                    from.SendMessage("The Wooden Boards Must Be In Your Backpack");
                }

                else if (okay)
                {
                    baseboards.Hue = m_PowderWoodDye.Hue;
                    from.SendMessage("You Dye The Wood");
                    m_PowderWoodDye.Delete();
                    from.PlaySound(0x23E);
                }
            }
            else
            {
                from.SendMessage("This Dye Only Works On Wooden Boards"); // Not the right target type
            }
        }
    }

    public class PowderWoodDye : Item
    {
        [Constructable]
        public PowderWoodDye() : base(0xE26)
        {
            base.Weight = 1.0;
            base.Name = "A Wood Dye Bottle";
        }

        public override void GetProperties(ObjectPropertyList list)
        {
            base.GetProperties(list);

            if (Hue == 0x15)
                list.Add(string.Format("Normal Wood Dye"));
            if (Hue == 0x763)
                list.Add(string.Format("Iron Wood Dye"));
            if (Hue == 0x973)
                list.Add(string.Format("Dull Copper Wood Dye"));
            if (Hue == 0x966)
                list.Add(string.Format("Shadow Wood Dye"));
            if (Hue == 0x96D)
                list.Add(string.Format("Copper Wood Dye"));
            if (Hue == 0x972)
                list.Add(string.Format("Bronze Wood Dye"));
            if (Hue == 0x8A5)
                list.Add(string.Format("Gold Wood Dye"));
            else if (Hue == 0x835)
                list.Add(string.Format("Silver Wood Dye"));
            else if (Hue == 0x979)
                list.Add(string.Format("Agapite Wood Dye"));
            else if (Hue == 0x89F)
                list.Add(string.Format("Verite Wood Dye"));
            else if (Hue == 0x8AB)
                list.Add(string.Format("Valorite Wood Dye"));
            else if (Hue == 0x583)
                list.Add(string.Format("Uridium Wood Dye"));
            else if (Hue == 0x91)
                list.Add(string.Format("Trillium Wood Dye"));
            else if (Hue == 0xBD)
                list.Add(string.Format("Titanium Wood Dye"));
            else if (Hue == 0x4D5)
                list.Add(string.Format("Platinum Wood Dye"));
            else if (Hue == 0xA4)
                list.Add(string.Format("Zenite Wood Dye"));
            else if (Hue == 0x2DD)
                list.Add(string.Format("Naquinite Wood Dye"));
            else if (Hue == 0x849)
                list.Add(string.Format("Galvinite Wood Dye"));
            else if (Hue == 0x674)
                list.Add(string.Format("Trilamide Wood Dye"));
            else if (Hue == 0x11C)
                list.Add(string.Format("Veramide Wood Dye"));
            else if (Hue == 0x47F)
                list.Add(string.Format("Zenlamide Wood Dye"));
            else if (Hue == 0x45)
                list.Add(string.Format("Etheral Wood Dye"));
        }

        public PowderWoodDye(Serial serial) : base(serial)
        {
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);
            writer.Write((int)0); // version
        }

        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
        }

        // DYE ACTION

        public override void OnDoubleClick(Mobile from) // Override double click of the deed to call our target
        {
            if (!IsChildOf(from.Backpack)) // Make sure its in their pack
            {
                from.SendMessage("The Bottle Must Be In Your Backpack To Use It."); // That must be in your pack for you to use it.
            }
            else
            {
                from.SendMessage("Which Wood Do You Want To Dye?");
                from.Target = new PowderWoodDyeTarget(this); // Call target
            }
        }
    }
}


